function pa = phase_aleatoire(M,N)

% pa = phase_aleatoire(M,N) calcule une realisation d'une phase aleatoire
% de taille (M,N).
% L'emplacement des frequences suit la convention fftshift(fft2()),
% autrement dit la fréquence nulle est au centre.
% M et N sont supposes pairs.
% Une  phase aleatoire est une image antisymetrique dont les elements sont
% des angles tires uniformement dans l'intervalle ]-pi,pi].

pa = zeros(M,N);


% tirage des phases aleatoires dans le demi-plan complexe :
for m = 1:(M/2+1)
    for n=1:N
        % cas 1 : (m,n) est son propre symétrique : on tire au hasard
        % entre 0 et pi.
        if( ((m==1)||(m==M/2+1)) && ((n==1)||(n==N/2+1)) )
            % pour la frequence nulle on impose 0 pour garder la moyenne.
            if( (m==1) && (n==1) )
                pa(m,n) = 0;
            else
                pa(m,n) = pi*(rand(1) > 0.5);
            end
        % cas 2 : le point symétrique de (m,n) est dans le meme demi-plan
        % complexe et sa phase aleatoire a deja ete tiree.
        elseif( ((m==1)||(m==M/2+1)) && (n>N/2+1) )
            ns = N-n+2;
            pa(m,n) = -pa(m,ns);
        % cas generique : on tire un angle uniformement dans ]-pi,pi[.
        else
            pa(m,n) = -pi + 2*pi*rand(1);
        end
    end
end


% completion de pa par symetrie.
for m = (M/2+2):M
    for n=1:N
        % calcul des coordonnees du pixel symetrique.
        ms = M-m+2;
        if(n==1)
            ns = 1;
        else
            ns = N-n+2;
        end
        pa(m,n) = -pa(ms,ns);
    end
end


% shift :
pa = fftshift(pa);


