function out = vis_mod_img(u, d, opt)
% vis_mod_img(u, d, opt) calcule une image pour visualiser le module de
% Fourier d'une image en niveau de gris,
% ENTREES :
% - u : image reelle en niveau de gris.
% - d : seuillage de d% des valeurs extremales (d=1 par defaut).
% - opt : option pour la visualisation : visualisation du module seuille si
% opt==0 ou de son logarithme si opt==1 (opt==1 par defaut).

% Valeurs par defaut si les entrees secondaires ne sont pas definies :
if(nargin < 3)
    opt = 1;
end
if(nargin<2)
    d = 1;
end

[M,N] = size(u);
% Calcul du module :
Mu = abs(fftshift(fft2(u)));

% Passage (optionnel) au logarithme :
if(opt == 1)
    Mu = log(1+Mu);
end

% Seuillage de d% des valeurs extremales du module (ou log du module) :
if(d>0)
    nd = ceil(M*N*d/100); % nombre de pixels a seuiller.
    val = Mu(:);
    val = sort(val);
    s = val(M*N - nd + 1); % valeur maximale pour le seuil.
    SMu = Mu.*(Mu <= s) + s*(Mu > s);
else
    SMu = Mu;
end

% Normalisation de l'histogramme [min,max] -> [0,255] :
val = SMu(:);
mi = min(val);
ma = max(val);
if( (ma-mi) >0 )
    r = ma -mi;
    out = 255/r*(SMu - mi);
else
    out = 0;
end

out = uint8(out);

% visualisation avec matlab
imagesc(out); colormap gray; axis image;
